/*
 * Copyright (C) 1999  Warren Jasper
 * All rights reserved.
 *
 */

/*
 * dio24.h
 */

/* General defines */

#define TRUE  1
#define FALSE 0
#define BYTE unsigned char
#define WORD unsigned short
#define LONG unsigned long

/* #define DEBUG  */

#ifndef PCI_VENDOR_ID_CBOARDS
#define PCI_VENDOR_ID_CBOARDS 0x1307
#endif

#ifndef PCI_DEVICE_ID_CBOARDS_DIO24
#define PCI_DEVICE_ID_CBOARDS_DIO24 0x0028
#endif

#define MAX_BOARDS           1   /* Right now only support 1 board */


/* Default device major number */
#ifndef DEFAULT_MAJOR_DEV
#define DEFAULT_MAJOR_DEV  125    /* Default Major Device Number */
#endif

#define ENABLE_INTERRUPTS FALSE  /* FALSE = disable ,  TRUE = enable           */
#define DIO_PORTS           3    /* 24 Digital I/O Ports (3 bytes)             */
#define PORT_MIN         0x200   /* minimum base address used in autodetecting */
#define PORT_MAX         0x3e0   /* maximum base address allowed by board      */
#define PORT_STEP        0x4     /* base step ( 4 bytes)                       */
#define BADR1_SIZE       0x80    /* region of the PCI 9050                     */
#define BADR2_SIZE       0x4     /* uses 4 bytes of registers                  */


/* I/O Register locations */

/* NOTE: base_reg to be found dynamically at boot time. Not hard coded into driver */

/* BADR1: These are 2 32-bit Word Registers */
#define PCI_INT_ADDR        (base1+0x4c)
#define PCI_CNTRL_ADDR      (base1+0x50)

/* BADR2: These are 4 8-Bit Word Registers */
#define DIO_PORTA           (base2)    /* Port A 8 bit I/O of 8255 */
#define DIO_PORTB           (base2+1)  /* Port B 8 bit I/O of 8255 */
#define DIO_PORTC           (base2+2)  /* Port C 4+4 bit of 8255 */
#define DIO_CNTRL_REG       (base2+3)  /* Mode and Direction Control Register */


/* Interrupt context data. Controls interrupt service handler */
typedef struct BOARD_REC {
  WORD base1;         /* Base1 address of DIO board       */
  WORD base2;         /* Base2 address of DIO board       */
  LONG control_reg;   /* BADR1 + 0x4c                     */
  int  irq;           /* IRQ inturrepts                   */
} BoardRec;

/* Values kept for each channel. */

typedef struct CHANNEL_REC {
  int  open;              /* Is channel device open()    */
  WORD value;             /* value of DIO Channel        */
  WORD addr;              /* address of the channel      */
  int mode;               /* mode for 8255               */
  unsigned short f_flags; /* flags sent by open()        */
} ChanRec;


/*************************************************************************
 * PCI 9050 Interrupt Status/Control BADR1+0x4c
 **************************************************************************/

#define INTE     0x1       /* Interrupt Enable     */
#define INTPOL   0x2       /* Interrupt Polarity   */
#define INT      0x4       /* Interrupt Status     */
#define PCIINT   0x40      /* PCI Interrupt Enable */


/*************************************************************************
 * PCI 9050 Interrupt Status/Control BADR1+0x50
 **************************************************************************/
#define OUT0   0x4    /* 0=10 Mhz, 1=1Mhz */

